/*
 * Licensed Materials - Property of IBM pidnumber (C) Copyright IBM Corporation
 * 2005. All Rights Reserved. US Government Users Restricted Rights- Use,
 * duplication or disclosure restricted by GSA ADP Schedule Contract with IBM
 * Corp.
 */
package com.ibm.j2ca.sample.twineball.emd;

import java.util.logging.Level;

import com.ibm.j2ca.extension.emd.PropertyNameHelper;
import com.ibm.j2ca.extension.emd.discovery.WBIMetadataDiscoveryImpl;
import com.ibm.j2ca.extension.emd.discovery.properties.WBIMultiValuedPropertyImpl;
import com.ibm.j2ca.extension.emd.discovery.properties.WBIPropertyVetoException;
import com.ibm.j2ca.extension.logging.LogUtils;

import commonj.connector.metadata.MetadataException;
import commonj.connector.metadata.discovery.properties.PropertyEvent;

public class ServiceTypeSingleProperty extends WBIMultiValuedPropertyImpl {

	private LogUtils logUtils;
    
    public ServiceTypeSingleProperty(String propertyName, Class propertyType, PropertyNameHelper helper) throws MetadataException {      
    	super(propertyName, propertyType, helper);
        this.logUtils = helper.getLogUtils();
    }

    public void propertyChange(PropertyEvent event) {
        super.propertyChange(event);

        String[] operations;
        if(logUtils != null){
    		this.logUtils.traceMethodEntrance("ServiceTypeSingleProperty", "propertyChange()");
        }
        if (event.getNewValue() != null) {
            //remove all current values.
            if (this.getValues().length > 0) {
                int length = this.getValues().length;
                for (int i = 0; i < length; i++) {
                    this.removeValue(0);
                }
            }
            if (event.getNewValue().equals("Inbound")) {
                this.setHidden(true);
                operations = TwineBallOperations.getInboundOperations();
                try {
                    setOperations(operations);
                } catch (MetadataException e) {
                    throw new RuntimeException(e);
                }
            } else {
                this.setHidden(false);
                operations = TwineBallOperations.getOutboundOperations();
                try {
                    setOperations(operations);
                } catch (MetadataException e) {
                    throw new RuntimeException(e);
                }
            }
            try {
                this.setValidValues(operations);
            } catch (MetadataException e) {
            	if(logUtils != null){
            		this.logUtils.trace(Level.WARNING, "ServiceTypePropertyChangeListener", "propertyChange()", "Exception:", e);
            	}
                throw new RuntimeException(e);
            }
        }
        if(logUtils != null){
    		this.logUtils.traceMethodExit("ServiceTypePropertyChangeListener", "propertyChange()");
        }
    }

    /**
     * @param operations
     * @throws MetadataException
     */
    private void setOperations(String[] operations) throws MetadataException {
        for (int i = 0; i < operations.length; i++) {
            this.addValue(operations[i]);
        }
    }

    public void vetoableChange(PropertyEvent evt) throws WBIPropertyVetoException {
    }
}