/*
 * Licensed Materials - Property of IBM pidnumber (C) Copyright IBM Corporation
 * 2005. All Rights Reserved. US Government Users Restricted Rights- Use,
 * duplication or disclosure restricted by GSA ADP Schedule Contract with IBM
 * Corp.
 */
package com.ibm.j2ca.sample.twineball.emd.discovery.connection;

import com.ibm.j2ca.extension.emd.EMDUtil;
import com.ibm.j2ca.extension.emd.PropertyNameHelper;
import com.ibm.j2ca.extension.emd.discovery.WBIMetadataDiscoveryImpl;
import com.ibm.j2ca.extension.emd.discovery.connection.WBIInboundConnectionConfigurationImpl;
import com.ibm.j2ca.extension.emd.discovery.connection.WBIInboundConnectionTypeImpl;
import com.ibm.j2ca.extension.emd.discovery.properties.WBIPropertyGroupImpl;
import com.ibm.j2ca.extension.emd.discovery.properties.WBISingleValuedPropertyImpl;
import com.ibm.j2ca.extension.logging.LogUtils;
import com.ibm.j2ca.sample.twineball.TwineBallResourceAdapter;
import com.ibm.j2ca.sample.twineball.emd.discovery.TwineBallMetadataSelection;
import com.ibm.j2ca.sample.twineball.inbound.TwineBallActivationSpecWithXid;
import commonj.connector.metadata.MetadataException;
import commonj.connector.metadata.discovery.properties.PropertyGroup;

/**
 * This is the connection configuration for inbound.
 */
public class TwineBallInboundConnectionConfiguration extends WBIInboundConnectionConfigurationImpl {
	private LogUtils logUtils;

	EMDUtil emdUtil;

	PropertyNameHelper helper;

    public TwineBallInboundConnectionConfiguration(WBIInboundConnectionTypeImpl connType, PropertyNameHelper helper) throws MetadataException {
        super(connType, helper);
        this.logUtils = helper.getLogUtils();
        emdUtil = new EMDUtil();
        this.helper = helper;
    }

    /*
     * (non-Javadoc)
     *
     * @see commonj.connector.metadata.discovery.connection.ConnectionConfiguration#getUnifiedProperties()
     */
    public PropertyGroup createUnifiedProperties() {
        WBIPropertyGroupImpl propGroup = null;
        try {
            propGroup = (WBIPropertyGroupImpl) createActivationSpecProperties();
            TwineBallResourceAdapter ra = new TwineBallResourceAdapter();
            WBIPropertyGroupImpl adapterProp = null;
            if(emdUtil != null){
            	adapterProp = (WBIPropertyGroupImpl) emdUtil.getPropertyGroup(ra,helper);
            }

	    if(adapterProp != null)
            	propGroup.addProperty(adapterProp);
            if (getAppliedProperties() != null){
            	if(emdUtil != null){
            		emdUtil.copyValues(getAppliedProperties(), propGroup,helper);
            	}
            }
        } catch (MetadataException e) {
            throw new RuntimeException(e);
        }
        return propGroup;
    }


    public PropertyGroup createActivationSpecProperties() {
        WBIPropertyGroupImpl connProp = null;
        try {
        	if(helper != null){
	            connProp = (WBIPropertyGroupImpl) emdUtil.getPropertyGroup(new TwineBallActivationSpecWithXid(), helper);
	            WBISingleValuedPropertyImpl namespaceProp = (WBISingleValuedPropertyImpl) connProp.getProperty("BONamespace"); //$NON-NLS-1$
	            namespaceProp.setValue(TwineBallMetadataSelection.getNamespace());
	            WBIPropertyGroupImpl credentialPropertyGroup = new WBIPropertyGroupImpl("UserCredentials", helper);
	            credentialPropertyGroup.setDisplayName(helper.getPropertyName("UserCredentials"));
	            credentialPropertyGroup.setDescription(helper.getPropertyDescription("UserCredentials"));
	            WBISingleValuedPropertyImpl property = new WBISingleValuedPropertyImpl("UserName", String.class, helper);
	            property.setRequired(false);
	            property.setDisplayName(helper.getPropertyName("UserName"));
	            property.setDescription(helper.getPropertyDescription("UserName"));
	            credentialPropertyGroup.addProperty(property);
	            property = new WBISingleValuedPropertyImpl("Password", String.class, helper);
	            property.setRequired(false);
	            property.setSensitive(true); //show it as **** on display
	            property.setDisplayName(helper.getPropertyName("Password"));
	            property.setDescription(helper.getPropertyDescription("Password"));
	            credentialPropertyGroup.addProperty(property);
	            connProp.addProperty(credentialPropertyGroup);
	            property = new WBISingleValuedPropertyImpl("Url", String.class,helper);
	            property.setRequired(false);
	            property.setDisplayName(helper.getPropertyName("Url"));
	            property.setDescription(helper.getPropertyDescription("Url"));
	            connProp.addProperty(property);
	            property = new WBISingleValuedPropertyImpl("EventTableName", String.class, helper);
	            property.setRequired(true);
	            property.setDisplayName(helper.getPropertyName("eventTableName"));
	            property.setDescription(helper.getPropertyDescription("eventTableName"));
	            property.setValue("WBIA_EVENTS");
	            connProp.addProperty(property);
		    connProp.setExpert(true);
	            if (getAppliedProperties() != null)
	                emdUtil.copyValues(getAppliedProperties(), connProp,helper);
        	}

        } catch (MetadataException e) {
            throw new RuntimeException(e);
        }
        return connProp;
    }



    public PropertyGroup createResourceAdapterProperties() {
        TwineBallResourceAdapter ra = new TwineBallResourceAdapter();
        WBIPropertyGroupImpl adapterProp = null;
        try {
        	if(emdUtil != null){
        		adapterProp = (WBIPropertyGroupImpl) emdUtil.getPropertyGroup(ra,helper);
        	}
            if (getAppliedProperties() != null && adapterProp != null){
            	if(emdUtil != null){
            		emdUtil.copyValues(getAppliedProperties(), adapterProp,helper);
            	}


            }
        } catch (Exception e) {
            throw new NullPointerException(e.getMessage());
        }
        return adapterProp;
    }
}